@@ -8,7 +8,7 @@ Script generate custom netapp filer .config and .rc based on XML config file
 __author__ = "Shah Mohsin WAHED <s.wahed@laposte.net>"
 __copyright__ = "Copyright (c) 2013 S.WAHED"
 __license__ = "GPL"
-__version__ = "1.5.2"
+__version__ = "1.5.3"
 __cvsversion__ = "$Revision: $"
 __date__ = "$Date: $"
 
@@ -34,12 +34,14 @@ import argparse
 from lxml import etree
 import os
 from Cheetah.Template import Template
+import re
 
 # this part contain all netapp command use python 2.x % vars to fill command
 # command format :
 # netapp command line with $(variable) for each variable you want to fill in
 #
-ifGroupConfigCSS = "ifgrp create %(lagType)s %(ifgroupename)s -b port %(port)s \n"
+ifGroupConfigCSS = "ifgrp create %(lagType)s %(ifgroupename)s -b %(lbmode)s %(port)s \n"
+ifGroupConfigSingleCSS = "ifgrp create %(lagType)s %(ifgroupename)s %(port)s \n"
 vlanConfigCSS = "vlan create %(ifgroupename)s %(vlanlist)s \n"
 ipspacesConfigCSS = "ipspace create %(ipspaceName)s %(ipspaceInterfaces)s \n"
 interfacesConfigCSS = "ifconfig %(interfaceName)s %(interfaceHostname)s netmask %(interfaceNetmask)s mtusize %(interfaceMtu)s partner %(interfaceName)s \n"
@@ -82,10 +84,14 @@ def ifGroupConfig():
     # then make config command using the ifGroupConfigCSS
     for ifgroups in rootTreeFiler.xpath('//ifgroups'):
         for ifgroup in ifgroups:
-            ifgroupename = ifgroup.get('name') + "-" + ifgroup.find('port').text.replace(' ', '')
+            ifgroupename = ifgroup.get('name') + "-" + "e" + re.sub('e', '', ifgroup.find('port').text.replace(' ', ''))
             port = ifgroup.find('port').text
             lagType = ifgroup.find('type').text
-            ifGroupConfigTxt += ifGroupConfigCSS % vars()
+            lbmode = ifgroup.find('lb').text
+            if lagType == "single":
+                ifGroupConfigTxt += ifGroupConfigSingleCSS % vars() 
+            else:
+                ifGroupConfigTxt += ifGroupConfigCSS % vars()
     return ifGroupConfigTxt
 
 
@@ -95,7 +101,7 @@ def vlanConfig():
     # cylcle on xml part with the ifgroupname short name (vm1 for exemple) we could find the correct port
     for ifgroups in rootTreeFiler.xpath('//ifgroups'):
         for ifgroup in ifgroups:
-            ifgroupename = ifgroup.get('name') + "-" + ifgroup.find('port').text.replace(' ', '')
+            ifgroupename = ifgroup.get('name') + "-" + "e" + re.sub('e', '', ifgroup.find('port').text.replace(' ', ''))
             vlanlist = ifgroup.find('vlans').text.strip()
             vlanConfigTxt += vlanConfigCSS % vars()
     return vlanConfigTxt
@@ -117,13 +123,13 @@ def interfacesConfig():
     interfacesConfigTxt = ""
     for interfaces in rootTreeFiler.xpath('//interfaces'):
         for interface in interfaces:
-            interfaceHostname = interface.get('hostnamename')
+            interfaceHostname = interface.get('hostname')
             interfaceName = interface.find('int').text.strip()
             interfaceNetmask = interface.find('netmask').text.strip()
             interfaceMtu = interface.find('mtu').text.strip()
             xpathsearchtext = '//ifgroups//ifgroup[@name="' + interfaceName + '"]'
             for ifgroup in rootTreeFiler.xpath(xpathsearchtext):
-                interfaceName = ifgroup.get('name') + "-" + ifgroup.find('port').text.replace(' ', '') + "-" + interface.find('vlan').text.strip()
+                interfaceName = ifgroup.get('name') + "-" + "e" + re.sub('e', '', ifgroup.find('port').text.replace(' ', '')) + "-" + interface.find('vlan').text.strip()
             interfacesConfigTxt += interfacesConfigCSS % vars()
     return interfacesConfigTxt
 
@@ -149,7 +155,7 @@ def vFilersConfig():
                     interfaceName = interface.find('int').text.strip()
                     xpathsearchtext = '//ifgroups//ifgroup[@name="' + interfaceName + '"]'
                     for ifgroup in rootTreeFiler.xpath(xpathsearchtext):
-                        interfaceName = ifgroup.get('name') + "-" + ifgroup.find('port').text.replace(' ', '') + "-" + interface.find('vlan').text.strip()
+                        interfaceName = ifgroup.get('name') + "-" + "e" + re.sub('e', '', ifgroup.find('port').text.replace(' ', '')) + "-" + interface.find('vlan').text.strip()
                     interfaceVlan = interface.find('vlan').text.strip()
                     interfaceIp = interface.find('ip').text.strip()
                     interfaceNetmask = interface.find('netmask').text.strip()
@@ -192,7 +198,7 @@ def vFilersInterfacesAndRoutes():
                     interfaceName = interface.find('int').text.strip()
                     xpathsearchtext = '//ifgroups//ifgroup[@name="' + interfaceName + '"]'
                     for ifgroup in rootTreeFiler.xpath(xpathsearchtext):
-                        interfaceName = ifgroup.get('name') + "-" + ifgroup.find('port').text.replace(' ', '') + "-" + interface.find('vlan').text.strip()
+                        interfaceName = ifgroup.get('name') + "-" + "e" + re.sub('e', '', ifgroup.find('port').text.replace(' ', '')) + "-" + interface.find('vlan').text.strip()
                     interfaceVlan = interface.find('vlan').text.strip()
                     interfaceIp = interface.find('ip').text.strip()
                     interfaceNetmask = interface.find('netmask').text.strip()
